==> fet_5.5.5.orig.tar.gz: fet-5.5.5/src/interface/addconstraintteachermaxgapsperdayform.h <==
/***************************************************************************
                          addconstraintteachermaxgapsperdayform.h  -  description
                             -------------------
    begin                : Jan 21, 2008
    copyright            : (C) 2008 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTTEACHERMAXGAPSPERDAYFORM_H
#define ADDCONSTRAINTTEACHERMAXGAPSPERDAYFORM_H

#include "addconstraintteachermaxgapsperdayform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"
//#include "fetmainform.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class AddConstraintTeacherMaxGapsPerDayForm : public AddConstraintTeacherMaxGapsPerDayForm_template  {
public:
	AddConstraintTeacherMaxGapsPerDayForm();
	~AddConstraintTeacherMaxGapsPerDayForm();

	void constraintChanged();
	void addCurrentConstraint();
};

#endif

==> fet_5.11.0.orig.tar.gz: fet-5.11.0/src/interface/addconstraintteachermaxgapsperdayform.h <==
/***************************************************************************
                          addconstraintteachermaxgapsperdayform.h  -  description
                             -------------------
    begin                : Jan 21, 2008
    copyright            : (C) 2008 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTTEACHERMAXGAPSPERDAYFORM_H
#define ADDCONSTRAINTTEACHERMAXGAPSPERDAYFORM_H

#include "ui_addconstraintteachermaxgapsperdayform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"
//#include "fetmainform.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class AddConstraintTeacherMaxGapsPerDayForm : public QDialog, Ui::AddConstraintTeacherMaxGapsPerDayForm_template  {
	Q_OBJECT
public:
	AddConstraintTeacherMaxGapsPerDayForm();
	~AddConstraintTeacherMaxGapsPerDayForm();

public slots:
	void constraintChanged();
	void addCurrentConstraint();
};

#endif
